@@ -108,14 +108,6 @@ module Vagrant
       error_key(:active_machine_with_different_provider)
     end
 
-    class AnsibleFailed < VagrantError
-      error_key(:ansible_failed)
-    end
-
-    class AnsiblePlaybookAppNotFound < VagrantError
-      error_key(:ansible_playbook_app_not_found)
-    end
-
     class BatchMultiError < VagrantError
       error_key(:batch_multi_error)
     end
@@ -248,6 +240,10 @@ module Vagrant
       error_key(:bundler_error)
     end
 
+    class CantReadMACAddresses < VagrantError
+      error_key(:cant_read_mac_addresses)
+    end
+
     class CapabilityHostExplicitNotDetected < VagrantError
       error_key(:capability_host_explicit_not_detected)
     end
@@ -288,6 +284,14 @@ module Vagrant
       error_key(:cli_invalid_options)
     end
 
+    class CloneNotFound < VagrantError
+      error_key(:clone_not_found)
+    end
+
+    class CloneMachineNotFound < VagrantError
+      error_key(:clone_machine_not_found)
+    end
+
     class CommandUnavailable < VagrantError
       error_key(:command_unavailable)
     end
@@ -316,6 +320,10 @@ module Vagrant
       error_key(:corrupt_machine_index)
     end
 
+    class DarwinMountFailed < VagrantError
+      error_key(:darwin_mount_failed)
+    end
+
     class DarwinNFSMountFailed < VagrantError
       error_key(:darwin_nfs_mount_failed)
     end
@@ -336,6 +344,10 @@ module Vagrant
       error_key(:downloader_interrupted)
     end
 
+    class EnvInval < VagrantError
+      error_key(:env_inval)
+    end
+
     class EnvironmentNonExistentCWD < VagrantError
       error_key(:environment_non_existent_cwd)
     end
@@ -396,8 +408,8 @@ module Vagrant
       error_key(:linux_nfs_mount_failed)
     end
 
-    class LinuxRDesktopNotFound < VagrantError
-      error_key(:linux_rdesktop_not_found)
+    class LinuxRDPClientNotFound < VagrantError
+      error_key(:linux_rdp_client_not_found)
     end
 
     class LocalDataDirectoryNotAccessible < VagrantError
@@ -476,6 +488,10 @@ module Vagrant
       error_key(:nfs_client_not_installed_in_guest)
     end
 
+    class NoDefaultProvider < VagrantError
+      error_key(:no_default_provider)
+    end
+
     class NoDefaultSyncedFolderImpl < VagrantError
       error_key(:no_default_synced_folder_impl)
     end
@@ -504,6 +520,18 @@ module Vagrant
       error_key(:requires_directory, "vagrant.actions.general.package")
     end
 
+    class ProviderCantInstall < VagrantError
+      error_key(:provider_cant_install)
+    end
+
+    class ProviderChecksumMismatch < VagrantError
+      error_key(:provider_checksum_mismatch)
+    end
+
+    class ProviderInstallFailed < VagrantError
+      error_key(:provider_install_failed)
+    end
+
     class ProviderNotFound < VagrantError
       error_key(:provider_not_found)
     end
@@ -552,6 +580,22 @@ module Vagrant
       error_key(:plugin_uninstall_system)
     end
 
+    class PushesNotDefined < VagrantError
+      error_key(:pushes_not_defined)
+    end
+
+    class PushStrategyNotDefined < VagrantError
+      error_key(:push_strategy_not_defined)
+    end
+
+    class PushStrategyNotLoaded < VagrantError
+      error_key(:push_strategy_not_loaded)
+    end
+
+    class PushStrategyNotProvided < VagrantError
+      error_key(:push_strategy_not_provided)
+    end
+
     class RSyncError < VagrantError
       error_key(:rsync_error)
     end
@@ -616,6 +660,10 @@ module Vagrant
       error_key(:ssh_invalid_shell)
     end
 
+    class SSHInsertKeyUnsupported < VagrantError
+      error_key(:ssh_insert_key_unsupported)
+    end
+
     class SSHIsPuttyLink < VagrantError
       error_key(:ssh_is_putty_link)
     end
@@ -692,6 +740,10 @@ module Vagrant
       error_key(:vboxmanage_error)
     end
 
+    class VBoxManageLaunchError < VagrantError
+      error_key(:vboxmanage_launch_error)
+    end
+
     class VBoxManageNotFoundError < VagrantError
       error_key(:vboxmanage_not_found_error)
     end
@@ -728,6 +780,18 @@ module Vagrant
       error_key(:virtualbox_no_name)
     end
 
+    class VirtualBoxNameExists < VagrantError
+      error_key(:virtualbox_name_exists)
+    end
+
+    class VirtualBoxUserMismatch < VagrantError
+      error_key(:virtualbox_user_mismatch)
+    end
+
+    class VirtualBoxVersionEmpty < VagrantError
+      error_key(:virtualbox_version_empty)
+    end
+
     class VMBaseMacNotSpecified < VagrantError
       error_key(:no_base_mac, "vagrant.actions.vm.match_mac")
     end
@@ -740,6 +804,14 @@ module Vagrant
       error_key(:boot_timeout)
     end
 
+    class VMCloneFailure < VagrantError
+      error_key(:failure, "vagrant.actions.vm.clone")
+    end
+
+    class VMCreateMasterFailure < VagrantError
+      error_key(:failure, "vagrant.actions.vm.clone.create_master")
+    end
+
     class VMCustomizationFailed < VagrantError
       error_key(:failure, "vagrant.actions.vm.customize")
     end
