@@ -22,8 +22,8 @@ module Vagrant
     # This will evaluate the block given to `register` and return the
     # resulting value.
     def get(key)
-      return nil if !@items.has_key?(key)
-      return @results_cache[key] if @results_cache.has_key?(key)
+      return nil if !@items.key?(key)
+      return @results_cache[key] if @results_cache.key?(key)
       @results_cache[key] = @items[key].call
     end
     alias :[] :get
@@ -31,10 +31,11 @@ module Vagrant
     # Checks if the given key is registered with the registry.
     #
     # @return [Boolean]
-    def has_key?(key)
-      @items.has_key?(key)
+    def key?(key)
+      @items.key?(key)
     end
-    
+    alias_method :has_key?, :key?
+
     # Returns an array populated with the keys of this object.
     #
     # @return [Array]
@@ -49,6 +50,21 @@ module Vagrant
       end
     end
 
+    # Return the number of elements in this registry.
+    #
+    # @return [Fixnum]
+    def length
+      @items.keys.length
+    end
+    alias_method :size, :length
+
+    # Checks if this registry has any items.
+    #
+    # @return [Boolean]
+    def empty?
+      @items.keys.empty?
+    end
+
     # Merge one registry with another and return a completely new
     # registry. Note that the result cache is completely busted, so
     # any gets on the new registry will result in a cache miss.
