@@ -34,20 +34,29 @@ module VagrantPlugins
             system = ", system" if plugin && plugin["system"]
             env[:ui].info "#{spec.name} (#{spec.version}#{system})"
             env[:ui].machine("plugin-name", spec.name)
-            env[:ui].machine("plugin-version", "#{spec.version}#{system}")
+            env[:ui].machine(
+              "plugin-version",
+              "#{spec.version}#{system}",
+              target: spec.name)
 
             if plugin["gem_version"] && plugin["gem_version"] != ""
               env[:ui].info(I18n.t(
                 "vagrant.commands.plugin.plugin_version",
                 version: plugin["gem_version"]))
-              env[:ui].machine("plugin-version-constraint", plugin["gem_version"])
+              env[:ui].machine(
+                "plugin-version-constraint",
+                plugin["gem_version"],
+                target: spec.name)
             end
 
             if plugin["require"] && plugin["require"] != ""
               env[:ui].info(I18n.t(
                 "vagrant.commands.plugin.plugin_require",
                 require: plugin["require"]))
-              env[:ui].machine("plugin-custom-entrypoint", plugin["require"])
+              env[:ui].machine(
+                "plugin-custom-entrypoint",
+                plugin["require"],
+                target: spec.name)
             end
           end
 
