@@ -76,7 +76,7 @@ module VagrantPlugins
             o.separator "For help on any individual command run `vagrant plugin COMMAND -h`"
           end
 
-          @env.ui.info(opts.help, :prefix => false)
+          @env.ui.info(opts.help, prefix: false)
         end
       end
     end
