@@ -11,15 +11,16 @@ module VagrantPlugins
         options = {}
 
         opts = OptionParser.new do |o|
-          o.banner = "Usage: vagrant ssh [vm-name] [-c command] [-- extra ssh args]"
-
+          o.banner = "Usage: vagrant ssh [options] [name] [-- extra ssh args]"
+          o.separator ""
+          o.separator "Options:"
           o.separator ""
 
-          o.on("-c", "--command COMMAND", "Execute an SSH command directly.") do |c|
+          o.on("-c", "--command COMMAND", "Execute an SSH command directly") do |c|
             options[:command] = c
           end
 
-          o.on("-p", "--plain", "Plain mode, leaves authentication up to user.") do |p|
+          o.on("-p", "--plain", "Plain mode, leaves authentication up to user") do |p|
             options[:plain_mode] = p
           end
         end
@@ -37,10 +38,10 @@ module VagrantPlugins
         return if !argv
 
         # Execute the actual SSH
-        with_target_vms(argv, :single_target => true) do |vm|
+        with_target_vms(argv, single_target: true) do |vm|
           ssh_opts = {
-            :plain_mode => options[:plain_mode],
-            :extra_args => options[:ssh_args]
+            plain_mode: options[:plain_mode],
+            extra_args: options[:ssh_args]
           }
 
           if options[:command]
@@ -55,7 +56,7 @@ module VagrantPlugins
             return exit_status
           else
             @logger.debug("Invoking `ssh` action on machine")
-            vm.action(:ssh, :ssh_opts => ssh_opts)
+            vm.action(:ssh, ssh_opts: ssh_opts)
 
             # We should never reach this point, since the point of `ssh`
             # is to exec into the proper SSH shell, but we'll just return
