@@ -11,6 +11,7 @@ module VagrantPlugins
       attr_accessor :timeout
       attr_accessor :transport
       attr_accessor :ssl_peer_verification
+      attr_accessor :execution_time_limit
 
       def initialize
         @username               = UNSET_VALUE
@@ -23,6 +24,7 @@ module VagrantPlugins
         @timeout                = UNSET_VALUE
         @transport              = UNSET_VALUE
         @ssl_peer_verification  = UNSET_VALUE
+        @execution_time_limit   = UNSET_VALUE
       end
 
       def finalize!
@@ -37,6 +39,7 @@ module VagrantPlugins
         @retry_delay = 2       if @retry_delay == UNSET_VALUE
         @timeout = 1800        if @timeout == UNSET_VALUE
         @ssl_peer_verification = true if @ssl_peer_verification == UNSET_VALUE
+        @execution_time_limit = "PT2H"   if @execution_time_limit == UNSET_VALUE
       end
 
       def validate(machine)
@@ -49,6 +52,7 @@ module VagrantPlugins
         errors << "winrm.max_tries cannot be nil."   if @max_tries.nil?
         errors << "winrm.retry_delay cannot be nil." if @max_tries.nil?
         errors << "winrm.timeout cannot be nil."     if @timeout.nil?
+        errors << "winrm.execution_time_limit cannot be nil."     if @execution_time_limit.nil?
         unless @ssl_peer_verification == true || @ssl_peer_verification == false
           errors << "winrm.ssl_peer_verification must be a boolean."
         end
