@@ -4,7 +4,7 @@ module VagrantPlugins
       class Halt
         def self.halt(machine)
           begin
-            machine.communicate.sudo("shutdown -p now", {:shell => "sh"})
+            machine.communicate.sudo("shutdown -p now", {shell: "sh"})
           rescue IOError
             # Do nothing because SSH connection closed and it probably
             # means the VM just shut down really fast.
