@@ -13,12 +13,12 @@ module VagrantPlugins
             # Remove any previous host only network additions to the interface file
             comm.sudo("sed -e '/^#VAGRANT-BEGIN/,/^#VAGRANT-END/ d' /etc/conf.d/net > /tmp/vagrant-network-interfaces")
             comm.sudo("cat /tmp/vagrant-network-interfaces > /etc/conf.d/net")
-            comm.sudo("rm /tmp/vagrant-network-interfaces")
+            comm.sudo("rm -f /tmp/vagrant-network-interfaces")
 
             # Configure each network interface
             networks.each do |network|
               entry = TemplateRenderer.render("guests/gentoo/network_#{network[:type]}",
-                                              :options => network)
+                                              options: network)
 
               # Upload the entry to a temporary location
               temp = Tempfile.new("vagrant")
@@ -32,7 +32,7 @@ module VagrantPlugins
               comm.sudo("ln -fs /etc/init.d/net.lo /etc/init.d/net.eth#{network[:interface]}")
               comm.sudo("/etc/init.d/net.eth#{network[:interface]} stop 2> /dev/null")
               comm.sudo("cat /tmp/vagrant-network-entry >> /etc/conf.d/net")
-              comm.sudo("rm /tmp/vagrant-network-entry")
+              comm.sudo("rm -f /tmp/vagrant-network-entry")
               comm.sudo("/etc/init.d/net.eth#{network[:interface]} start")
             end
           end
