@@ -12,6 +12,23 @@ module VagrantPlugins
         include Vagrant::Util
 
         def self.configure_networks(machine, networks)
+          case machine.guest.capability("flavor")
+          when :rhel_7
+            configure_networks_rhel7(machine, networks)
+          else
+            configure_networks_default(machine, networks)
+          end
+        end
+
+        def self.configure_networks_rhel7(machine, networks)
+          # This is kind of jank but the configure networks is the same
+          # as Fedora at this point.
+          require File.expand_path("../../../fedora/cap/configure_networks", __FILE__)
+          ::VagrantPlugins::GuestFedora::Cap::ConfigureNetworks.
+            configure_networks(machine, networks)
+        end
+
+        def self.configure_networks_default(machine, networks)
           network_scripts_dir = machine.guest.capability("network_scripts_dir")
 
           # Accumulate the configurations to add to the interfaces file as
@@ -31,12 +48,12 @@ module VagrantPlugins
             machine.communicate.sudo("touch #{network_scripts_dir}/ifcfg-eth#{network[:interface]}")
             machine.communicate.sudo("sed -e '/^#VAGRANT-BEGIN/,/^#VAGRANT-END/ d' #{network_scripts_dir}/ifcfg-eth#{network[:interface]} > /tmp/vagrant-ifcfg-eth#{network[:interface]}")
             machine.communicate.sudo("cat /tmp/vagrant-ifcfg-eth#{network[:interface]} > #{network_scripts_dir}/ifcfg-eth#{network[:interface]}")
-            machine.communicate.sudo("rm /tmp/vagrant-ifcfg-eth#{network[:interface]}")
+            machine.communicate.sudo("rm -f /tmp/vagrant-ifcfg-eth#{network[:interface]}")
 
             # Render and upload the network entry file to a deterministic
             # temporary location.
             entry = TemplateRenderer.render("guests/redhat/network_#{network[:type]}",
-                                            :options => network)
+                                            options: network)
 
             temp = Tempfile.new("vagrant")
             temp.binmode
@@ -50,7 +67,7 @@ module VagrantPlugins
           # each specifically, we avoid reconfiguring eth0 (the NAT interface) so
           # SSH never dies.
           interfaces.each do |interface|
-            retryable(:on => Vagrant::Errors::VagrantError, :tries => 3, :sleep => 2) do
+            retryable(on: Vagrant::Errors::VagrantError, tries: 3, sleep: 2) do
               # The interface should already be down so this probably
               # won't do anything, so we run it with error_check false.
               machine.communicate.sudo(
@@ -61,7 +78,7 @@ module VagrantPlugins
               machine.communicate.sudo("ARPCHECK=no /sbin/ifup eth#{interface} 2> /dev/null")
             end
 
-            machine.communicate.sudo("rm /tmp/vagrant-network-entry_#{interface}")
+            machine.communicate.sudo("rm -f /tmp/vagrant-network-entry_#{interface}")
           end
         end
       end
