@@ -11,7 +11,7 @@ module VagrantPlugins
           output.chomp!
 
           # Detect various flavors we care about
-          if output =~ /(CentOS|Red Hat Enterprise) Linux( .+)? release 7/i
+          if output =~ /(CentOS|Red Hat Enterprise|Scientific) Linux( .+)? release 7/i
             return :rhel_7
           else
             return :rhel
