@@ -9,7 +9,8 @@ module VagrantPlugins
           #
           # does not exist in /etc/user_attr. TODO
           begin
-            machine.communicate.execute("#{machine.config.solaris.suexec_cmd} /usr/sbin/poweroff")
+            machine.communicate.execute(
+              "#{machine.config.solaris.suexec_cmd} /usr/sbin/shutdown -y -i5 -g0")
           rescue IOError
             # Ignore, this probably means connection closed because it
             # shut down.
