@@ -17,10 +17,10 @@ module VagrantPlugins
         end
 
         def self.rsync_post(machine, opts)
-          su_cmd = machine.config.solaris11.su_cmd
+          suexec_cmd = machine.config.solaris11.suexec_cmd
           machine.communicate.execute(
-            "#{su_cmd} '#{opts[:guestpath]}' '(' ! -user #{opts[:owner]} -or ! -group #{opts[:group]} ')' -print0 | " +
-              "xargs -0 -r chown #{opts[:owner]}:#{opts[:group]}")
+            "#{suexec_cmd} '#{opts[:guestpath]}' '(' ! -user #{opts[:owner]} -or ! -group #{opts[:group]} ')' -print0 | " +
+              "xargs -0 chown #{opts[:owner]}:#{opts[:group]}")
         end
       end
     end
