@@ -1,5 +1,5 @@
 module VagrantPlugins
-  module GuestSuse
+  module GuestSUSE
     module Cap
       class ChangeHostName
         def self.change_host_name(machine, name)
@@ -8,6 +8,7 @@ module VagrantPlugins
             if !comm.test("sudo hostname | grep '#{name}'")
               comm.sudo("echo #{name} > /etc/HOSTNAME")
               comm.sudo("hostname #{name}")
+
               comm.sudo("sed -i 's@^\\(127[.]0[.]0[.]1[[:space:]]\\+\\)@\\1#{name} #{name.split('.')[0]} @' /etc/hosts")
             end
           end
