@@ -1,10 +1,10 @@
 require "vagrant"
 
 module VagrantPlugins
-  module GuestSuse
+  module GuestSUSE
     class Guest < Vagrant.plugin("2", :guest)
       def detect?(machine)
-        machine.communicate.test("cat /etc/SuSE-release")
+        machine.communicate.test("test -f /etc/SuSE-release || grep -q SUSE /etc/os-release")
       end
     end
   end
