@@ -6,10 +6,6 @@ module VagrantPlugins
         error_namespace("vagrant_windows.errors")
       end
 
-      class CantReadMACAddresses < WindowsError
-        error_key(:cant_read_mac_addresses)
-      end
-
       class NetworkWinRMRequired < WindowsError
         error_key(:network_winrm_required)
       end
