@@ -3,8 +3,8 @@ require "vagrant"
 module VagrantPlugins
   module HostRedHat
     class Plugin < Vagrant.plugin("2")
-      name "Red Hat host"
-      description "Red Hat host support."
+      name "Red Hat Enterprise Linux host"
+      description "Red Hat Enterprise Linux host support."
 
       host("redhat", "linux") do
         require File.expand_path("../host", __FILE__)
