@@ -5,12 +5,16 @@ module VagrantPlugins
       attr_accessor :port
       attr_accessor :private_key_path
       attr_accessor :username
+      attr_accessor :password
+      attr_accessor :insert_key
 
       def initialize
         @host             = UNSET_VALUE
         @port             = UNSET_VALUE
         @private_key_path = UNSET_VALUE
         @username         = UNSET_VALUE
+        @password         = UNSET_VALUE
+        @insert_key       = UNSET_VALUE
       end
 
       def finalize!
@@ -18,6 +22,8 @@ module VagrantPlugins
         @port             = nil if @port == UNSET_VALUE
         @private_key_path = nil if @private_key_path == UNSET_VALUE
         @username         = nil if @username == UNSET_VALUE
+        @password         = nil if @password == UNSET_VALUE
+        @insert_key       = true if @insert_key == UNSET_VALUE
 
         if @private_key_path && !@private_key_path.is_a?(Array)
           @private_key_path = [@private_key_path]
