@@ -4,16 +4,16 @@ module VagrantPlugins
   module Kernel_V2
     # Represents a single configured provisioner for a VM.
     class VagrantConfigProvisioner
-      # Unique ID name for this provisioner
+      # Unique name for this provisioner
       #
       # @return [String]
-      attr_reader :id
+      attr_reader :name
 
-      # The name of the provisioner that should be registered
+      # The type of the provisioner that should be registered
       # as a plugin.
       #
       # @return [Symbol]
-      attr_reader :name
+      attr_reader :type
 
       # The configuration associated with the provisioner, if there is any.
       #
@@ -31,30 +31,30 @@ module VagrantPlugins
       # @return [Boolean]
       attr_accessor :preserve_order
 
-      def initialize(id, name)
+      def initialize(name, type)
         @logger = Log4r::Logger.new("vagrant::config::vm::provisioner")
         @logger.debug("Provisioner defined: #{name}")
 
         @config  = nil
-        @id      = id
         @invalid = false
         @name    = name
         @preserve_order = false
         @run     = nil
+        @type    = type
 
         # Attempt to find the provisioner...
-        if !Vagrant.plugin("2").manager.provisioners[name]
-          @logger.warn("Provisioner '#{name}' not found.")
+        if !Vagrant.plugin("2").manager.provisioners[type]
+          @logger.warn("Provisioner '#{type}' not found.")
           @invalid = true
         end
 
         # Attempt to find the configuration class for this provider
         # if it exists and load the configuration.
         @config_class = Vagrant.plugin("2").manager.
-          provisioner_configs[@name]
+          provisioner_configs[@type]
         if !@config_class
           @logger.info(
-            "Provisioner config for '#{@name}' not found. Ignoring config.")
+            "Provisioner config for '#{@type}' not found. Ignoring config.")
           @config_class = Vagrant::Config::V2::DummyConfig
         end
       end
