@@ -1,3 +1,4 @@
+require "ipaddr"
 require "set"
 
 require "log4r"
@@ -147,7 +148,7 @@ module VagrantPlugins
         def bridged_adapter(config)
           # Find the bridged interfaces that are available
           bridgedifs = @env[:machine].provider.driver.read_bridged_interfaces
-          bridgedifs.delete_if { |interface| interface[:status] == "Down" }
+          bridgedifs.delete_if { |interface| interface[:status] == "Down" || interface[:status] == "Unknown" }
 
           # The name of the chosen bridge interface will be assigned to this
           # variable.
@@ -248,8 +249,7 @@ module VagrantPlugins
             auto_config: true,
             mac:         nil,
             nic_type:    nil,
-            netmask:     "255.255.255.0",
-            type:        :static
+            type:        :static,
           }.merge(options)
 
           # Make sure the type is a symbol
@@ -258,31 +258,47 @@ module VagrantPlugins
           # Default IP is in the 20-bit private network block for DHCP based networks
           options[:ip] = "172.28.128.1" if options[:type] == :dhcp && !options[:ip]
 
-          # Calculate our network address for the given IP/netmask
-          netaddr  = network_address(options[:ip], options[:netmask])
+          ip = IPAddr.new(options[:ip])
+          if ip.ipv4?
+            options[:netmask] ||= "255.255.255.0"
 
-          # Verify that a host-only network subnet would not collide
-          # with a bridged networking interface.
-          #
-          # If the subnets overlap in any way then the host only network
-          # will not work because the routing tables will force the
-          # traffic onto the real interface rather than the VirtualBox
-          # interface.
-          @env[:machine].provider.driver.read_bridged_interfaces.each do |interface|
-            that_netaddr = network_address(interface[:ip], interface[:netmask])
-            raise Vagrant::Errors::NetworkCollision if \
-              netaddr == that_netaddr && interface[:status] != "Down"
+            # Calculate our network address for the given IP/netmask
+            netaddr  = network_address(options[:ip], options[:netmask])
+
+            # Verify that a host-only network subnet would not collide
+            # with a bridged networking interface.
+            #
+            # If the subnets overlap in any way then the host only network
+            # will not work because the routing tables will force the
+            # traffic onto the real interface rather than the VirtualBox
+            # interface.
+            @env[:machine].provider.driver.read_bridged_interfaces.each do |interface|
+              that_netaddr = network_address(interface[:ip], interface[:netmask])
+              raise Vagrant::Errors::NetworkCollision if \
+                netaddr == that_netaddr && interface[:status] != "Down"
+            end
+
+            # Split the IP address into its components
+            ip_parts = netaddr.split(".").map { |i| i.to_i }
+
+            # Calculate the adapter IP, which we assume is the IP ".1" at
+            # the end usually.
+            adapter_ip    = ip_parts.dup
+            adapter_ip[3] += 1
+            options[:adapter_ip] ||= adapter_ip.join(".")
+          elsif ip.ipv6?
+            # Default subnet prefix length
+            options[:netmask] ||= 64
+
+            # Set adapter IP to <prefix>::1
+            options[:adapter_ip] ||= (ip.mask(options[:netmask].to_i) | 1).to_s
+
+            # Append a 6 to the end of the type
+            options[:type] = "#{options[:type]}6".to_sym
+          else
+            raise "BUG: Unknown IP type: #{ip.inspect}"
           end
 
-          # Split the IP address into its components
-          ip_parts = netaddr.split(".").map { |i| i.to_i }
-
-          # Calculate the adapter IP, which we assume is the IP ".1" at
-          # the end usually.
-          adapter_ip    = ip_parts.dup
-          adapter_ip[3] += 1
-          options[:adapter_ip] ||= adapter_ip.join(".")
-
           dhcp_options = {}
           if options[:type] == :dhcp
             # Calculate the DHCP server IP, which is the network address
@@ -456,8 +472,16 @@ module VagrantPlugins
 
           @env[:machine].provider.driver.read_host_only_interfaces.each do |interface|
             return interface if config[:name] && config[:name] == interface[:name]
-            return interface if this_netaddr == \
-              network_address(interface[:ip], interface[:netmask])
+
+            if interface[:ip] != ""
+              return interface if this_netaddr == \
+                network_address(interface[:ip], interface[:netmask])
+            end
+
+            if interface[:ipv6] != ""
+              return interface if this_netaddr == \
+                network_address(interface[:ipv6], interface[:ipv6_prefix])
+            end
           end
 
           nil
