@@ -1,7 +1,10 @@
+require "vagrant/action/builtin/mixin_synced_folders"
+
 module VagrantPlugins
   module ProviderVirtualBox
     module Action
       class PrepareNFSSettings
+        include Vagrant::Action::Builtin::MixinSyncedFolders
         include Vagrant::Util::Retryable
 
         def initialize(app, env)
@@ -14,19 +17,19 @@ module VagrantPlugins
 
           @app.call(env)
 
-          if using_nfs?
+          opts = {
+            cached: !!env[:synced_folders_cached],
+            config: env[:synced_folders_config],
+            disable_usable_check: !!env[:test],
+          }
+          folders = synced_folders(env[:machine], **opts)
+
+          if folders.key?(:nfs)
             @logger.info("Using NFS, preparing NFS settings by reading host IP and machine IP")
             add_ips_to_env!(env)
           end
         end
 
-        # We're using NFS if we have any synced folder with NFS configured. If
-        # we are not using NFS we don't need to do the extra work to
-        # populate these fields in the environment.
-        def using_nfs?
-          @machine.config.vm.synced_folders.any? { |_, opts| opts[:type] == :nfs }
-        end
-
         # Extracts the proper host and guest IPs for NFS mounts and stores them
         # in the environment for the SyncedFolder action to use them in
         # mounting.
@@ -67,7 +70,7 @@ module VagrantPlugins
         def read_static_machine_ips
           ips = []
           @machine.config.vm.networks.each do |type, options|
-            if type == :private_network && options[:ip].is_a?(String)
+            if type == :private_network && options[:type] != :dhcp && options[:ip].is_a?(String)
               ips << options[:ip]
             end
           end
