@@ -7,12 +7,12 @@ require File.expand_path("../base", __FILE__)
 module VagrantPlugins
   module ProviderVirtualBox
     module Driver
-      # Driver for VirtualBox 4.2.x
-      class Version_4_2 < Base
+      # Driver for VirtualBox 4.1.x
+      class Version_4_1 < Base
         def initialize(uuid)
           super()
 
-          @logger = Log4r::Logger.new("vagrant::provider::virtualbox_4_2")
+          @logger = Log4r::Logger.new("vagrant::provider::virtualbox_4_1")
           @uuid = uuid
         end
 
@@ -28,8 +28,8 @@ module VagrantPlugins
         def clear_shared_folders
           info = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
           info.split("\n").each do |line|
-            if line =~ /^SharedFolderNameMachineMapping\d+="(.+?)"$/
-              execute("sharedfolder", "remove", @uuid, "--name", $1.to_s)
+            if folder = line[/^SharedFolderNameMachineMapping\d+="(.+?)"$/, 1]
+              execute("sharedfolder", "remove", @uuid, "--name", folder)
             end
           end
         end
@@ -45,13 +45,22 @@ module VagrantPlugins
 
         def create_host_only_network(options)
           # Create the interface
-          execute("hostonlyif", "create") =~ /^Interface '(.+?)' was successfully created$/
-            name = $1.to_s
+          interface = execute("hostonlyif", "create")
+          name = interface[/^Interface '(.+?)' was successfully created$/, 1]
 
-          # Configure it
-          execute("hostonlyif", "ipconfig", name,
-                  "--ip", options[:adapter_ip],
-                  "--netmask", options[:netmask])
+          # Get the IP so we can determine v4 vs v6
+          ip = IPAddr.new(options[:adapter_ip])
+
+          # Configure
+          if ip.ipv4?
+            execute("hostonlyif", "ipconfig", name,
+                    "--ip", options[:adapter_ip],
+                    "--netmask", options[:netmask])
+          elsif ip.ipv6?
+            execute("hostonlyif", "ipconfig", name,
+                    "--ipv6", options[:adapter_ip],
+                    "--netmasklengthv6", options[:netmask].to_s)
+          end
 
           # Return the details
           return {
@@ -69,15 +78,17 @@ module VagrantPlugins
         def delete_unused_host_only_networks
           networks = []
           execute("list", "hostonlyifs").split("\n").each do |line|
-            networks << $1.to_s if line =~ /^Name:\s+(.+?)$/
+            if network = line[/^Name:\s+(.+?)$/, 1]
+              networks << network
+            end
           end
 
           execute("list", "vms").split("\n").each do |line|
-            if line =~ /^".+?"\s+\{(.+?)\}$/
-              info = execute("showvminfo", $1.to_s, "--machinereadable", retryable: true)
-              info.split("\n").each do |inner_line|
-                if inner_line =~ /^hostonlyadapter\d+="(.+?)"$/
-                  networks.delete($1.to_s)
+            if vm = line[/^".+?"\s+\{(.+?)\}$/, 1]
+              info = execute("showvminfo", vm, "--machinereadable", retryable: true)
+              info.split("\n").each do |line|
+                if adapter = line[/^hostonlyadapter\d+="(.+?)"$/, 1]
+                  networks.delete(adapter)
                 end
               end
             end
@@ -110,12 +121,12 @@ module VagrantPlugins
 
             if adapter[:hostonly]
               args.concat(["--hostonlyadapter#{adapter[:adapter]}",
-                          adapter[:hostonly], "--cableconnected#{adapter[:adapter]}", "on"])
+                          adapter[:hostonly]])
             end
 
             if adapter[:intnet]
               args.concat(["--intnet#{adapter[:adapter]}",
-                          adapter[:intnet], "--cableconnected#{adapter[:adapter]}", "on"])
+                          adapter[:intnet]])
             end
 
             if adapter[:mac_address]
@@ -166,36 +177,7 @@ module VagrantPlugins
           output = ""
           total = ""
           last  = 0
-
-          output = execute("import", "-n", ovf)
-          output =~ /Suggested VM name "(.+?)"/
-          suggested_name = $1.to_s
-          specified_name = "#{suggested_name}_#{(Time.now.to_f * 1000.0).to_i}_#{rand(100000)}" #Millisecond + Random
-
-          #Build the specified name param list
-          name_params = Array.new
-          name_params << "--vsys" << "0" << "--vmname" << specified_name
-
-          #Extract the disks list and build the disk target params
-          disk_params = Array.new
-          disks = output.scan(/(\d+): Hard disk image: source image=.+, target path=(.+),/)
-          disks.each do |unit_num, path|
-            disk_params << "--vsys"
-            disk_params << "0"  #Derive vsys num .. do we support OVF's with multiple machines?
-            disk_params << "--unit"
-            disk_params << unit_num
-            disk_params << "--disk"
-            if Vagrant::Util::Platform.windows?
-              # we use the block form of sub here to ensure that if the specified_name happens to end with a number (which is fairly likely) then
-              # we won't end up having the character sequence of a \ followed by a number be interpreted as a back reference.  For example, if
-              # specified_name were "abc123", then "\\abc123\\".reverse would be "\\321cba\\", and the \3 would be treated as a back reference by the sub
-              disk_params << path.reverse.sub("\\#{suggested_name}\\".reverse) { "\\#{specified_name}\\".reverse }.reverse # Replace only last occurrence
-            else
-              disk_params << path.reverse.sub("/#{suggested_name}/".reverse, "/#{specified_name}/".reverse).reverse # Replace only last occurrence
-            end
-          end
-
-          execute("import", ovf , *name_params, *disk_params) do |type, data|
+          execute("import", ovf) do |type, data|
             if type == :stdout
               # Keep track of the stdout so that we can get the VM name
               output << data
@@ -208,8 +190,8 @@ module VagrantPlugins
               if lines.include?("OK.")
                 # The progress of the import will be in the last line. Do a greedy
                 # regular expression to find what we're looking for.
-                if lines.last =~ /.+(\d{2})%/
-                  current = $1.to_i
+                if current = lines.last[/.+(\d{2})%/, 1]
+                  current = current.to_i
                   if current > last
                     last = current
                     yield current if block_given?
@@ -219,19 +201,21 @@ module VagrantPlugins
             end
           end
 
-          output = execute("list", "vms")
+          # Find the name of the VM name
+          name = output[/Suggested VM name "(.+?)"/, 1]
+          if !name
+            @logger.error("Couldn't find VM name in the output.")
+            return nil
+          end
 
-          if output =~ /^"#{Regexp.escape(specified_name)}" \{(.+?)\}$/
-            return $1.to_s
+          output = execute("list", "vms")
+          if existing_vm = output[/^"#{Regexp.escape(name)}" \{(.+?)\}$/, 1]
+            return existing_vm
           end
 
           nil
         end
 
-        def max_network_adapters
-          36
-        end
-
         def read_forwarded_ports(uuid=nil, active_only=false)
           uuid ||= @uuid
 
@@ -243,17 +227,19 @@ module VagrantPlugins
           info.split("\n").each do |line|
             # This is how we find the nic that a FP is attached to,
             # since this comes first.
-            current_nic = $1.to_i if line =~ /^nic(\d+)=".+?"$/
+            if nic = line[/^nic(\d+)=".+?"$/, 1]
+              current_nic = nic.to_i
+            end
 
-              # If we care about active VMs only, then we check the state
-              # to verify the VM is running.
-              if active_only && line =~ /^VMState="(.+?)"$/ && $1.to_s != "running"
-                return []
-              end
+            # If we care about active VMs only, then we check the state
+            # to verify the VM is running.
+            if active_only && (state = line[/^VMState="(.+?)"$/, 1] and state != "running")
+              return []
+            end
 
             # Parse out the forwarded port information
-            if line =~ /^Forwarding.+?="(.+?),.+?,.*?,(.+?),.*?,(.+?)"$/
-              result = [current_nic, $1.to_s, $2.to_i, $3.to_i]
+            if matcher = /^Forwarding.+?="(.+?),.+?,.*?,(.+?),.*?,(.+?)"$/.match(line)
+              result = [current_nic, matcher[1], matcher[2].to_i, matcher[3].to_i]
               @logger.debug("  - #{result.inspect}")
               results << result
             end
@@ -267,14 +253,14 @@ module VagrantPlugins
             info = {}
 
             block.split("\n").each do |line|
-              if line =~ /^Name:\s+(.+?)$/
-                info[:name] = $1.to_s
-              elsif line =~ /^IPAddress:\s+(.+?)$/
-                info[:ip] = $1.to_s
-              elsif line =~ /^NetworkMask:\s+(.+?)$/
-                info[:netmask] = $1.to_s
-              elsif line =~ /^Status:\s+(.+?)$/
-                info[:status] = $1.to_s
+              if name = line[/^Name:\s+(.+?)$/, 1]
+                info[:name] = name
+              elsif ip = line[/^IPAddress:\s+(.+?)$/, 1]
+                info[:ip] = ip
+              elsif netmask = line[/^NetworkMask:\s+(.+?)$/, 1]
+                info[:netmask] = netmask
+              elsif status = line[/^Status:\s+(.+?)$/, 1]
+                info[:status] = status
               end
             end
 
@@ -309,21 +295,13 @@ module VagrantPlugins
         def read_guest_additions_version
           output = execute("guestproperty", "get", @uuid, "/VirtualBox/GuestAdd/Version",
                            retryable: true)
-          if output =~ /^Value: (.+?)$/
+          if value = output[/^Value: (.+?)$/, 1]
             # Split the version by _ since some distro versions modify it
             # to look like this: 4.1.2_ubuntu, and the distro part isn't
             # too important.
-            value = $1.to_s
             return value.split("_").first
           end
 
-          # If we can't get the guest additions version by guest property, try
-          # to get it from the VM info itself.
-          info = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
-          info.split("\n").each do |line|
-            return $1.to_s if line =~ /^GuestAdditionsVersion="(.+?)"$/
-          end
-
           return nil
         end
 
@@ -350,14 +328,18 @@ module VagrantPlugins
             info = {}
 
             block.split("\n").each do |line|
-              if line =~ /^Name:\s+(.+?)$/
-                info[:name] = $1.to_s
-              elsif line =~ /^IPAddress:\s+(.+?)$/
-                info[:ip] = $1.to_s
-              elsif line =~ /^NetworkMask:\s+(.+?)$/
-                info[:netmask] = $1.to_s
-              elsif line =~ /^Status:\s+(.+?)$/
-                info[:status] = $1.to_s
+              if name = line[/^Name:\s+(.+?)$/, 1]
+                info[:name] = name
+              elsif ip = line[/^IPAddress:\s+(.+?)$/, 1]
+                info[:ip] = ip
+              elsif netmask = line[/^NetworkMask:\s+(.+?)$/, 1]
+                info[:netmask] = netmask
+              elsif line =~ /^IPV6Address:\s+(.+?)$/
+                info[:ipv6] = $1.to_s.strip
+              elsif line =~ /^IPV6NetworkMaskPrefixLength:\s+(.+?)$/
+                info[:ipv6_prefix] = $1.to_s.strip
+              elsif status = line[/^Status:\s+(.+?)$/, 1]
+                info[:status] = status
               end
             end
 
@@ -368,7 +350,9 @@ module VagrantPlugins
         def read_mac_address
           info = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
           info.split("\n").each do |line|
-            return $1.to_s if line =~ /^macaddress1="(.+?)"$/
+            if mac = line[/^macaddress1="(.+?)"$/, 1]
+              return mac
+            end
           end
 
           nil
@@ -389,8 +373,8 @@ module VagrantPlugins
 
         def read_machine_folder
           execute("list", "systemproperties", retryable: true).split("\n").each do |line|
-            if line =~ /^Default machine folder:\s+(.+?)$/i
-              return $1.to_s
+            if folder = line[/^Default machine folder:\s+(.+?)$/i, 1]
+              return folder
             end
           end
 
@@ -401,21 +385,21 @@ module VagrantPlugins
           nics = {}
           info = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
           info.split("\n").each do |line|
-            if line =~ /^nic(\d+)="(.+?)"$/
-              adapter = $1.to_i
-              type    = $2.to_sym
+            if matcher = /^nic(\d+)="(.+?)"$/.match(line)
+              adapter = matcher[1].to_i
+              type    = matcher[2].to_sym
 
               nics[adapter] ||= {}
               nics[adapter][:type] = type
-            elsif line =~ /^hostonlyadapter(\d+)="(.+?)"$/
-              adapter = $1.to_i
-              network = $2.to_s
+            elsif matcher = /^hostonlyadapter(\d+)="(.+?)"$/.match(line)
+              adapter = matcher[1].to_i
+              network = matcher[2].to_s
 
               nics[adapter] ||= {}
               nics[adapter][:hostonly] = network
-            elsif line =~ /^bridgeadapter(\d+)="(.+?)"$/
-              adapter = $1.to_i
-              network = $2.to_s
+            elsif matcher = /^bridgeadapter(\d+)="(.+?)"$/.match(line)
+              adapter = matcher[1].to_i
+              network = matcher[2].to_s
 
               nics[adapter] ||= {}
               nics[adapter][:bridge] = network
@@ -429,8 +413,8 @@ module VagrantPlugins
           output = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
           if output =~ /^name="<inaccessible>"$/
             return :inaccessible
-          elsif output =~ /^VMState="(.+?)"$/
-            return $1.to_sym
+          elsif state = output[/^VMState="(.+?)"$/, 1]
+            return state.to_sym
           end
 
           nil
@@ -439,9 +423,7 @@ module VagrantPlugins
         def read_used_ports
           ports = []
           execute("list", "vms", retryable: true).split("\n").each do |line|
-            if line =~ /^".+?" \{(.+?)\}$/
-              uuid = $1.to_s
-
+            if uuid = line[/^".+?" \{(.+?)\}$/, 1]
               # Ignore our own used ports
               next if uuid == @uuid
 
@@ -465,6 +447,11 @@ module VagrantPlugins
           results
         end
 
+        def reconfig_host_only(interface)
+          execute("hostonlyif", "ipconfig", interface[:name],
+                  "--ipv6", interface[:ipv6])
+        end
+
         def remove_dhcp_server(network_name)
           execute("dhcpserver", "remove", "--netname", network_name)
         end
@@ -474,7 +461,7 @@ module VagrantPlugins
         end
 
         def set_name(name)
-          execute("modifyvm", @uuid, "--name", name, retryable: true)
+          execute("modifyvm", @uuid, "--name", name)
         end
 
         def share_folders(folders)
