@@ -33,6 +33,16 @@ module VagrantPlugins
         require_relative "cap"
         Cap
       end
+
+      provider_capability(:virtualbox, :public_address) do
+        require_relative "cap/public_address"
+        Cap::PublicAddress
+      end
+
+      provider_capability(:virtualbox, :snapshot_list) do
+        require_relative "cap"
+        Cap
+      end
     end
 
     autoload :Action, File.expand_path("../action", __FILE__)
