@@ -14,9 +14,19 @@ module VagrantPlugins
               logger.info("Installing CFEngine Community Yum Repository GPG KEY from #{config.repo_gpg_key_url}")
               comm.sudo("GPGFILE=$(mktemp) && wget -O $GPGFILE #{config.repo_gpg_key_url} && rpm --import $GPGFILE; rm -f $GPGFILE")
 
-              comm.sudo("yum -y install #{config.package_name}")
+              if dnf?(machine)
+                comm.sudo("dnf -y install #{config.package_name}")
+              else
+                comm.sudo("yum -y install #{config.package_name}")
+              end
             end
           end
+
+          protected
+
+          def self.dnf?(machine)
+            machine.communicate.test("/usr/bin/which -s dnf")
+          end
         end
       end
     end
