@@ -1,9 +1,13 @@
+require "vagrant/util/presence"
+
 require_relative "base_runner"
 
 module VagrantPlugins
   module Chef
     module Config
       class ChefSolo < BaseRunner
+        include Vagrant::Util::Presence
+
         # The path on disk where Chef cookbooks are stored.
         # Default is "cookbooks".
         # @return [String]
@@ -17,6 +21,10 @@ module VagrantPlugins
         # @return [String]
         attr_accessor :environments_path
 
+        # The path where nodes are stored on disk.
+        # @return [String]
+        attr_accessor :nodes_path
+
         # A URL download a remote recipe from. Note: you should use chef-apply
         # instead.
         #
@@ -39,36 +47,12 @@ module VagrantPlugins
           @cookbooks_path      = UNSET_VALUE
           @data_bags_path      = UNSET_VALUE
           @environments_path   = UNSET_VALUE
+          @nodes_path          = UNSET_VALUE
           @recipe_url          = UNSET_VALUE
           @roles_path          = UNSET_VALUE
           @synced_folder_type  = UNSET_VALUE
         end
 
-        # @deprecated This is deprecated in Chef and will be removed in Chef 12.
-        def recipe_url=(value)
-          puts "DEPRECATION: The 'recipe_url' setting for the Chef Solo"
-          puts "provisioner is deprecated. This value will be removed in"
-          puts "Chef 12. It is recommended you use the Chef Apply provisioner"
-          puts "instead. The 'recipe_url' setting will be removed in the next"
-          puts "version of Vagrant."
-
-          if value
-            @recipe_url = value
-          end
-        end
-
-        def nfs=(value)
-          puts "DEPRECATION: The 'nfs' setting for the Chef Solo provisioner is"
-          puts "deprecated. Please use the 'synced_folder_type' setting instead."
-          puts "The 'nfs' setting will be removed in the next version of Vagrant."
-
-          if value
-            @synced_folder_type = "nfs"
-          else
-            @synced_folder_type = nil
-          end
-        end
-
         #------------------------------------------------------------
         # Internal methods
         #------------------------------------------------------------
@@ -86,6 +70,7 @@ module VagrantPlugins
           end
 
           @data_bags_path    = [] if @data_bags_path == UNSET_VALUE
+          @nodes_path        = [] if @nodes_path == UNSET_VALUE
           @roles_path        = [] if @roles_path == UNSET_VALUE
           @environments_path = [] if @environments_path == UNSET_VALUE
           @environments_path = [@environments_path].flatten
@@ -93,6 +78,7 @@ module VagrantPlugins
           # Make sure the path is an array.
           @cookbooks_path    = prepare_folders_config(@cookbooks_path)
           @data_bags_path    = prepare_folders_config(@data_bags_path)
+          @nodes_path        = prepare_folders_config(@nodes_path)
           @roles_path        = prepare_folders_config(@roles_path)
           @environments_path = prepare_folders_config(@environments_path)
         end
@@ -100,11 +86,11 @@ module VagrantPlugins
         def validate(machine)
           errors = validate_base(machine)
 
-          if [cookbooks_path].flatten.compact.empty?
+          if !present?(Array(cookbooks_path))
             errors << I18n.t("vagrant.config.chef.cookbooks_path_empty")
           end
 
-          if environment && environments_path.empty?
+          if environment && !present?(environments_path)
             errors << I18n.t("vagrant.config.chef.environment_path_required")
           end
 
