@@ -1,7 +1,10 @@
 require 'tempfile'
 
+require "vagrant/util/presence"
 require "vagrant/util/template_renderer"
 
+require_relative "../installer"
+
 module VagrantPlugins
   module Chef
     module Provisioner
@@ -9,25 +12,63 @@ module VagrantPlugins
       # chef-solo and chef-client provisioning are stored. This is **not an actual
       # provisioner**. Instead, {ChefSolo} or {ChefServer} should be used.
       class Base < Vagrant.plugin("2", :provisioner)
+        include Vagrant::Util::Presence
+
         class ChefError < Vagrant::Errors::VagrantError
           error_namespace("vagrant.provisioners.chef")
         end
 
+        def initialize(machine, config)
+          super
+
+          @logger = Log4r::Logger.new("vagrant::provisioners::chef")
+
+          if !present?(@config.node_name)
+            cache = @machine.data_dir.join("chef_node_name")
+
+            if !cache.exist?
+              @machine.ui.info I18n.t("vagrant.provisioners.chef.generating_node_name")
+              cache.open("w+") do |f|
+                f.write("vagrant-#{SecureRandom.hex(4)}")
+              end
+            end
+
+            if cache.file?
+              @logger.info("Loading cached node_name...")
+              @config.node_name = cache.read.strip
+            end
+          end
+        end
+
+        def install_chef
+          return if !config.install
+
+          @logger.info("Checking for Chef installation...")
+          installer = Installer.new(@machine,
+            product: config.product,
+            channel: config.channel,
+            version: config.version,
+            force: config.install == :force,
+            download_path:  config.installer_download_path
+          )
+          installer.ensure_installed
+        end
+
         def verify_binary(binary)
           # Checks for the existence of chef binary and error if it
           # doesn't exist.
+          if windows?
+            command = "if ((&'#{binary}' -v) -Match 'Chef: *'){ exit 0 } else { exit 1 }"
+          else
+            command = "sh -c 'command -v #{binary}'"
+          end
+
           @machine.communicate.sudo(
-            "which #{binary}",
+            command,
             error_class: ChefError,
             error_key: :chef_not_detected,
-            binary: binary)
-        end
-
-        # This returns the command to run Chef for the given client
-        # type.
-        def build_command(client)
-          builder = CommandBuilder.new(@config, client, windows?, @machine.env.ui.is_a?(Vagrant::UI::Colored))
-          return builder.build_command
+            binary: binary,
+          )
         end
 
         # Returns the path to the Chef binary, taking into account the
@@ -38,14 +79,20 @@ module VagrantPlugins
         end
 
         def chown_provisioning_folder
-          paths = [@config.provisioning_path,
-                   @config.file_backup_path,
-                   @config.file_cache_path]
+          paths = [
+            guest_provisioning_path,
+            guest_file_backup_path,
+            guest_file_cache_path,
+          ]
 
           @machine.communicate.tap do |comm|
             paths.each do |path|
-              comm.sudo("mkdir -p #{path}")
-              comm.sudo("chown -h #{@machine.ssh_info[:username]} #{path}")
+              if windows?
+                comm.sudo("mkdir ""#{path}"" -f")
+              else
+                comm.sudo("mkdir -p #{path}")
+                comm.sudo("chown -h #{@machine.ssh_info[:username]} #{path}")
+              end
             end
           end
         end
@@ -57,7 +104,7 @@ module VagrantPlugins
             expanded = File.expand_path(
               @config.custom_config_path, @machine.env.root_path)
             remote_custom_config_path = File.join(
-              config.provisioning_path, "custom-config.rb")
+              guest_provisioning_path, "custom-config.rb")
 
             @machine.communicate.upload(expanded, remote_custom_config_path)
           end
@@ -66,11 +113,12 @@ module VagrantPlugins
             custom_configuration: remote_custom_config_path,
             encrypted_data_bag_secret: guest_encrypted_data_bag_secret_key_path,
             environment:      @config.environment,
-            file_cache_path:  @config.file_cache_path,
-            file_backup_path: @config.file_backup_path,
+            file_cache_path:  guest_file_cache_path,
+            file_backup_path: guest_file_backup_path,
             log_level:        @config.log_level.to_sym,
             node_name:        @config.node_name,
             verbose_logging:  @config.verbose_logging,
+            enable_reporting: @config.enable_reporting,
             http_proxy:       @config.http_proxy,
             http_proxy_user:  @config.http_proxy_user,
             http_proxy_pass:  @config.http_proxy_pass,
@@ -87,7 +135,7 @@ module VagrantPlugins
           temp.write(config_file)
           temp.close
 
-          remote_file = File.join(config.provisioning_path, filename)
+          remote_file = File.join(guest_provisioning_path, filename)
           @machine.communicate.tap do |comm|
             comm.sudo("rm -f #{remote_file}", error_check: false)
             comm.upload(temp.path, remote_file)
@@ -95,11 +143,12 @@ module VagrantPlugins
         end
 
         def setup_json
-          @machine.env.ui.info I18n.t("vagrant.provisioners.chef.json")
+          @machine.ui.info I18n.t("vagrant.provisioners.chef.json")
 
           # Get the JSON that we're going to expose to Chef
           json = @config.json
-          json[:run_list] = @config.run_list if !@config.run_list.empty?
+          json[:run_list] = @config.run_list if @config.run_list &&
+            !@config.run_list.empty?
           json = JSON.pretty_generate(json)
 
           # Create a temporary file to store the data so we
@@ -108,9 +157,15 @@ module VagrantPlugins
           temp.write(json)
           temp.close
 
-          remote_file = File.join(@config.provisioning_path, "dna.json")
+          remote_file = File.join(guest_provisioning_path, "dna.json")
           @machine.communicate.tap do |comm|
-            comm.sudo("rm -f #{remote_file}", error_check: false)
+            if windows?
+              command = "if (test-path '#{remote_file}') {rm '#{remote_file}' -force -recurse}"
+            else
+              command = "rm -f #{remote_file}"
+            end
+
+            comm.sudo(command, error_check: false)
             comm.upload(temp.path, remote_file)
           end
         end
@@ -119,11 +174,17 @@ module VagrantPlugins
           remote_file = guest_encrypted_data_bag_secret_key_path
           return if !remote_file
 
-          @machine.env.ui.info I18n.t(
+          @machine.ui.info I18n.t(
             "vagrant.provisioners.chef.upload_encrypted_data_bag_secret_key")
 
           @machine.communicate.tap do |comm|
-            comm.sudo("rm -f #{remote_file}", error_check: false)
+            if windows?
+              command = "if (test-path ""#{remote_file}"") {rm ""#{remote_file}"" -force -recurse}"
+            else
+              command = "rm -f #{remote_file}"
+            end
+
+            comm.sudo(command, error_check: false)
             comm.upload(encrypted_data_bag_secret_key_path, remote_file)
           end
         end
@@ -131,7 +192,13 @@ module VagrantPlugins
         def delete_encrypted_data_bag_secret
           remote_file = guest_encrypted_data_bag_secret_key_path
           if remote_file
-            @machine.communicate.sudo("rm -f #{remote_file}", error_check: false)
+            if windows?
+              command = "if (test-path ""#{remote_file}"") {rm ""#{remote_file}"" -force -recurse}"
+            else
+              command = "rm -f #{remote_file}"
+            end
+
+            @machine.communicate.sudo(command, error_check: false)
           end
         end
 
@@ -142,7 +209,43 @@ module VagrantPlugins
 
         def guest_encrypted_data_bag_secret_key_path
           if @config.encrypted_data_bag_secret_key_path
-            File.join(@config.provisioning_path, "encrypted_data_bag_secret_key")
+            File.join(guest_provisioning_path, "encrypted_data_bag_secret_key")
+          end
+        end
+
+        def guest_provisioning_path
+          if !@config.provisioning_path.nil?
+            return @config.provisioning_path
+          end
+
+          if windows?
+            "C:/vagrant-chef"
+          else
+            "/tmp/vagrant-chef"
+          end
+        end
+
+        def guest_file_backup_path
+          if !@config.file_backup_path.nil?
+            return @config.file_backup_path
+          end
+
+          if windows?
+            "C:/chef/backup"
+          else
+            "/var/chef/backup"
+          end
+        end
+
+        def guest_file_cache_path
+          if !@config.file_cache_path.nil?
+            return @config.file_cache_path
+          end
+
+          if windows?
+            "C:/chef/cache"
+          else
+            "/var/chef/cache"
           end
         end
 
