@@ -6,6 +6,7 @@ module VagrantPlugins
       attr_accessor :functional
       attr_accessor :map_uid
       attr_accessor :map_gid
+      attr_accessor :verify_installed
 
       def initialize
         super
@@ -13,12 +14,14 @@ module VagrantPlugins
         @functional = UNSET_VALUE
         @map_uid    = UNSET_VALUE
         @map_gid    = UNSET_VALUE
+        @verify_installed = UNSET_VALUE
       end
 
       def finalize!
         @functional = true if @functional == UNSET_VALUE
         @map_uid = :auto if @map_uid == UNSET_VALUE
         @map_gid = :auto if @map_gid == UNSET_VALUE
+        @verify_installed = true if @verify_installed == UNSET_VALUE
       end
 
       def to_s
