@@ -1,26 +1,37 @@
 require "vagrant"
 require Vagrant.source_root.join("test/unit/base")
 
+require Vagrant.source_root.join("plugins/providers/virtualbox/config")
 require Vagrant.source_root.join("plugins/providers/virtualbox/synced_folder")
 
-# TODO(mitchellh): tag with v2
 describe VagrantPlugins::ProviderVirtualBox::SyncedFolder do
   let(:machine) do
     double("machine").tap do |m|
+      m.stub(provider_config: VagrantPlugins::ProviderVirtualBox::Config.new)
+      m.stub(provider_name: :virtualbox)
     end
   end
 
   subject { described_class.new }
 
+  before do
+    machine.provider_config.finalize!
+  end
+
   describe "usable" do
     it "should be with virtualbox provider" do
       machine.stub(provider_name: :virtualbox)
-      subject.should be_usable(machine)
+      expect(subject).to be_usable(machine)
     end
 
     it "should not be with another provider" do
       machine.stub(provider_name: :vmware_fusion)
-      subject.should_not be_usable(machine)
+      expect(subject).not_to be_usable(machine)
+    end
+
+    it "should not be usable if not functional vboxsf" do
+      machine.provider_config.functional_vboxsf = false
+      expect(subject).to_not be_usable(machine)
     end
   end
 
