@@ -1,6 +1,8 @@
 require "tempfile"
 require "tmpdir"
 
+require "vagrant/util/platform"
+
 require "unit/support/isolated_environment"
 
 shared_context "unit" do
@@ -12,6 +14,9 @@ shared_context "unit" do
     # Create a thing to store our temporary files so that they aren't
     # unlinked right away.
     @_temp_files = []
+
+    # Roughly simulate the embedded Bundler availability
+    $vagrant_bundler_runtime = Object.new
   end
 
   after(:each) do
@@ -55,18 +60,16 @@ shared_context "unit" do
   #
   # @return [Pathname]
   def temporary_file(contents=nil)
-    f = Tempfile.new("vagrant-unit")
+    dir = temporary_dir
+    f = dir.join("tempfile")
 
-    if contents
+    contents ||= ""
+    f.open("w") do |f|
       f.write(contents)
       f.flush
     end
 
-    # Store the tempfile in an instance variable so that it is not
-    # garbage collected, so that the tempfile is not unlinked.
-    @_temp_files << f
-
-    return Pathname.new(f.path)
+    return Pathname.new(Vagrant::Util::Platform.fs_real_path(f.to_s))
   end
 
   # This creates a temporary directory and returns a {Pathname}
@@ -77,10 +80,25 @@ shared_context "unit" do
     # Create a temporary directory and append it to the instance
     # variabe so that it isn't garbage collected and deleted
     d = Dir.mktmpdir("vagrant")
+    @_temp_files ||= []
     @_temp_files << d
 
     # Return the pathname
-    return Pathname.new(d)
+    result = Pathname.new(Vagrant::Util::Platform.fs_real_path(d))
+    yield result if block_given?
+    return result
+  end
+
+  # Stub the given environment in ENV, without actually touching ENV. Keys and
+  # values are converted to strings because that's how the real ENV works.
+  def stub_env(hash)
+    allow(ENV).to receive(:[]).and_call_original
+
+    hash.each do |key, value|
+      allow(ENV).to receive(:[])
+        .with(key.to_s)
+        .and_return(value.to_s)
+    end
   end
 
   # This helper provides temporary environmental variable changes.
@@ -89,6 +107,7 @@ shared_context "unit" do
     # can replace them back in later.
     old_env = {}
     environment.each do |key, value|
+      key          = key.to_s
       old_env[key] = ENV[key]
       ENV[key]     = value
     end
@@ -101,4 +120,18 @@ shared_context "unit" do
       ENV[key] = value
     end
   end
+
+  # This helper provides a randomly available port(s) for each argument to the
+  # block.
+  def with_random_port(&block)
+    ports = []
+
+    block.arity.times do
+      server = TCPServer.new('127.0.0.1', 0)
+      ports << server.addr[1]
+      server.close
+    end
+
+    block.call(*ports)
+  end
 end
