@@ -4,11 +4,13 @@ require "tempfile"
 require "tmpdir"
 require "webrick"
 
+require "fake_ftp"
+
 require File.expand_path("../../../../base", __FILE__)
 
 require "vagrant/util/file_checksum"
 
-describe Vagrant::Action::Builtin::BoxAdd do
+describe Vagrant::Action::Builtin::BoxAdd, :skip_windows do
   include_context "unit"
 
   let(:app) { lambda { |env| } }
@@ -34,6 +36,25 @@ describe Vagrant::Action::Builtin::BoxAdd do
     FileChecksum.new(path, Digest::SHA1).checksum
   end
 
+  def with_ftp_server(path, **opts)
+    path = Pathname.new(path)
+
+    tf = Tempfile.new("vagrant")
+    tf.close
+
+    port = nil
+    server = nil
+    with_random_port do |port1, port2|
+      port = port1
+      server = FakeFtp::Server.new(port1, port2)
+    end
+    server.add_file(path.basename, path.read)
+    server.start
+    yield port
+  ensure
+    server.stop rescue nil
+  end
+
   def with_web_server(path, **opts)
     tf = Tempfile.new("vagrant")
     tf.close
@@ -123,6 +144,26 @@ describe Vagrant::Action::Builtin::BoxAdd do
       end
     end
 
+    it "adds from FTP URL" do
+      box_path = iso_env.box2_file(:virtualbox)
+      with_ftp_server(box_path) do |port|
+        env[:box_name] = "foo"
+        env[:box_url] = "ftp://127.0.0.1:#{port}/#{box_path.basename}"
+
+        expect(box_collection).to receive(:add).with { |path, name, version, **opts|
+          expect(checksum(path)).to eq(checksum(box_path))
+          expect(name).to eq("foo")
+          expect(version).to eq("0")
+          expect(opts[:metadata_url]).to be_nil
+          true
+        }.and_return(box)
+
+        expect(app).to receive(:call).with(env)
+
+        subject.call(env)
+      end
+    end
+
     it "raises an error if no name is given" do
       box_path = iso_env.box2_file(:virtualbox)
 
@@ -166,6 +207,28 @@ describe Vagrant::Action::Builtin::BoxAdd do
         to raise_error(Vagrant::Errors::BoxChecksumMismatch)
     end
 
+    it "does not raise an error if the checksum has different case" do
+      box_path = iso_env.box2_file(:virtualbox)
+
+      box = double(
+        name: "foo",
+        version: "1.2.3",
+        provider: "virtualbox",
+      )
+
+      env[:box_name] = box.name
+      env[:box_url] = box_path.to_s
+      env[:box_checksum] = checksum(box_path)
+      env[:box_checksum_type] = "sha1"
+
+      # Convert to a different case
+      env[:box_checksum].upcase!
+
+      expect(box_collection).to receive(:add).and_return(box)
+
+      expect { subject.call(env) }.to_not raise_error
+    end
+
     it "raises an error if the box path doesn't exist" do
       box_path = iso_env.box2_file(:virtualbox)
 
