@@ -28,19 +28,47 @@ describe Vagrant::Action::Builtin::MixinSyncedFolders do
     end
   end
 
-  let(:vm_config) { double("machine_vm_config") }
+  let(:vm_config) { double("machine_vm_config", :allowed_synced_folder_types => nil) }
 
   describe "default_synced_folder_type" do
     it "returns the usable implementation" do
       plugins = {
         "bad" => [impl(false, "bad"), 0],
-        "nope" => [impl(true, "nope"), 1],
-        "good" => [impl(true, "good"), 5],
+        "good" => [impl(true, "good"), 1],
+        "best" => [impl(true, "best"), 5],
+      }
+
+      result = subject.default_synced_folder_type(machine, plugins)
+      expect(result).to eq("best")
+    end
+
+    it "filters based on allowed_synced_folder_types" do
+      expect(vm_config).to receive(:allowed_synced_folder_types).and_return(["bad", "good"])
+      plugins = {
+        "bad" => [impl(false, "bad"), 0],
+        "good" => [impl(true, "good"), 1],
+        "best" => [impl(true, "best"), 5],
       }
 
       result = subject.default_synced_folder_type(machine, plugins)
       expect(result).to eq("good")
     end
+
+    it "reprioritizes based on allowed_synced_folder_types" do
+      plugins = {
+        "bad" => [impl(false, "bad"), 0],
+        "good" => [impl(true, "good"), 1],
+        "same" => [impl(true, "same"), 1],
+      }
+
+      expect(vm_config).to receive(:allowed_synced_folder_types).and_return(["good", "same"])
+      result = subject.default_synced_folder_type(machine, plugins)
+      expect(result).to eq("good")
+
+      expect(vm_config).to receive(:allowed_synced_folder_types).and_return(["same", "good"])
+      result = subject.default_synced_folder_type(machine, plugins)
+      expect(result).to eq("same")
+    end
   end
 
   describe "impl_opts" do
@@ -86,11 +114,13 @@ describe Vagrant::Action::Builtin::MixinSyncedFolders do
       result = subject.synced_folders(machine)
       expect(result.length).to eq(2)
       expect(result[:default]).to eq({
-        "another" => folders["another"],
-        "foo" => folders["foo"],
-        "root" => folders["root"],
+        "another" => folders["another"].merge(__vagrantfile: true),
+        "foo" => folders["foo"].merge(__vagrantfile: true),
+        "root" => folders["root"].merge(__vagrantfile: true),
+      })
+      expect(result[:nfs]).to eq({
+        "nfs" => folders["nfs"].merge(__vagrantfile: true),
       })
-      expect(result[:nfs]).to eq({ "nfs" => folders["nfs"] })
     end
 
     it "should return the proper set of folders of a custom config" do
@@ -157,16 +187,20 @@ describe Vagrant::Action::Builtin::MixinSyncedFolders do
       result = subject.synced_folders(machine, cached: true)
       expect(result.length).to eq(2)
       expect(result[:default]).to eq({
-        "another" => old_folders["another"],
-        "foo" => old_folders["foo"],
-        "root" => old_folders["root"],
+        "another" => old_folders["another"].merge(__vagrantfile: true),
+        "foo" => old_folders["foo"].merge(__vagrantfile: true),
+        "root" => old_folders["root"].merge(__vagrantfile: true),
       })
-      expect(result[:nfs]).to eq({ "nfs" => old_folders["nfs"] })
+      expect(result[:nfs]).to eq({ "nfs" => old_folders["nfs"].merge(__vagrantfile: true) })
     end
 
     it "should be able to save and retrieve cached versions" do
-      folders["foo"] = { type: "default" }
-      result = subject.synced_folders(machine)
+      other_folders = {}
+      other = double("config")
+      other.stub(synced_folders: other_folders)
+
+      other_folders["foo"] = { type: "default" }
+      result = subject.synced_folders(machine, config: other)
       subject.save_synced_folders(machine, result)
 
       # Clear the folders and set some more
@@ -184,10 +218,36 @@ describe Vagrant::Action::Builtin::MixinSyncedFolders do
       expect(result.length).to eq(2)
       expect(result[:default]).to eq({
         "foo" => { type: "default" },
-        "bar" => { type: "default" },
+        "bar" => { type: "default", __vagrantfile: true},
       })
       expect(result[:nfs]).to eq({
-        "baz" => { type: "nfs" }
+        "baz" => { type: "nfs", __vagrantfile: true }
+      })
+    end
+
+    it "should remove items from the vagrantfile that were removed" do
+      folders["foo"] = { type: "default" }
+      result = subject.synced_folders(machine)
+      subject.save_synced_folders(machine, result)
+
+      # Clear the folders and set some more
+      folders.clear
+      folders["bar"] = { type: "default" }
+      folders["baz"] = { type: "nfs" }
+      result = subject.synced_folders(machine)
+      subject.save_synced_folders(machine, result, merge: true, vagrantfile: true)
+
+      # Clear one last time
+      folders.clear
+
+      # Read them all back
+      result = subject.synced_folders(machine, cached: true)
+      expect(result.length).to eq(2)
+      expect(result[:default]).to eq({
+        "bar" => { type: "default", __vagrantfile: true},
+      })
+      expect(result[:nfs]).to eq({
+        "baz" => { type: "nfs", __vagrantfile: true }
       })
     end
   end
