@@ -11,17 +11,20 @@ describe Vagrant::Errors::VagrantError do
     subject { klass.new }
 
     it "should use the translation for the message" do
-      subject.to_s.should == "test value"
+      expect(subject.to_s).to eq("test value")
     end
 
-    its("status_code") { should eq(1) }
+    describe '#status_code' do
+      subject { super().status_code }
+      it { should eq(1) }
+    end
   end
 
   describe "passing error key through options" do
     subject { described_class.new(_key: "test_key") }
 
     it "should use the translation for the message" do
-      subject.to_s.should == "test value"
+      expect(subject.to_s).to eq("test value")
     end
   end
 
@@ -32,10 +35,22 @@ describe Vagrant::Errors::VagrantError do
       end
     end
 
-    subject { klass.new }
+    subject { klass.new(data: "yep") }
 
     it "should use the translation for the message" do
-      subject.to_s.should == "foo"
+      expect(subject.to_s).to eq("foo")
+    end
+
+    it "should expose translation keys to the user" do
+      expect(subject.extra_data.length).to eql(1)
+      expect(subject.extra_data).to have_key(:data)
+      expect(subject.extra_data[:data]).to eql("yep")
+    end
+
+    it "should use a symbol initializer as a key" do
+      subject = klass.new(:test_key)
+      expect(subject.extra_data).to be_empty
+      expect(subject.to_s).to eql("test value")
     end
   end
 end
