@@ -15,9 +15,9 @@ describe FileChecksum do
 
     # Check multiple digests
     instance = described_class.new(file, Digest::MD5)
-    instance.checksum.should == "9ac96c64417b5976a58839eceaa77956"
+    expect(instance.checksum).to eq("9ac96c64417b5976a58839eceaa77956")
 
     instance = described_class.new(file, Digest::SHA1)
-    instance.checksum.should == "264b207c7913e461c43d0f63d2512f4017af4755"
+    expect(instance.checksum).to eq("264b207c7913e461c43d0f63d2512f4017af4755")
   end
 end
